gapipy.resources.booking package
================================

Submodules
----------

gapipy.resources.booking.agency module
--------------------------------------

.. automodule:: gapipy.resources.booking.agency
    :members:
    :undoc-members:
    :show-inheritance:

gapipy.resources.booking.agent module
-------------------------------------

.. automodule:: gapipy.resources.booking.agent
    :members:
    :undoc-members:
    :show-inheritance:

gapipy.resources.booking.booking module
---------------------------------------

.. automodule:: gapipy.resources.booking.booking
    :members:
    :undoc-members:
    :show-inheritance:

gapipy.resources.booking.customer module
----------------------------------------

.. automodule:: gapipy.resources.booking.customer
    :members:
    :undoc-members:
    :show-inheritance:

gapipy.resources.booking.document module
----------------------------------------

.. automodule:: gapipy.resources.booking.document
    :members:
    :undoc-members:
    :show-inheritance:

gapipy.resources.booking.nationality module
-------------------------------------------

.. automodule:: gapipy.resources.booking.nationality
    :members:
    :undoc-members:
    :show-inheritance:

gapipy.resources.booking.service module
---------------------------------------

.. automodule:: gapipy.resources.booking.service
    :members:
    :undoc-members:
    :show-inheritance:

gapipy.resources.booking.transaction module
-------------------------------------------

.. automodule:: gapipy.resources.booking.transaction
    :members:
    :undoc-members:
    :show-inheritance:


Module contents
---------------

.. automodule:: gapipy.resources.booking
    :members:
    :undoc-members:
    :show-inheritance:
